# aionova

A simple asyncio Python library to interact with the Anova Precision Cooker. 

## Getting your cooker_id/cooker_secret

See the advice given here: 

https://github.com/bmedicke/anova.py/issues/1#issuecomment-446835744

## Credits

  * Based on @bmedicke's library https://github.com/bmedicke/anova.py